# Changelog
*********************************
## MetaTiME 1.2.2 (Dec 18, 2022)
Add MetaTiME Differental signature updated docstring ; pypi setup
## MetaTiME 1.2.1 (Dec 16, 2022)
beta version: MetaTiME mecmapper and annotator with updated annotation
## MetaTiME 0.1.0 (Apr 12, 2022)
beta version: MetaTiME mecmapper and annotator

